==> okta-sdk-api-19.0.1-sources.jar: com/okta/sdk/resource/model/UserSchemaPropertiesProfileItem.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * UserSchemaPropertiesProfileItem
 */
@JsonPropertyOrder({ UserSchemaPropertiesProfileItem.JSON_PROPERTY_$_REF })
@javax.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2024-10-04T18:50:18.667445-05:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class UserSchemaPropertiesProfileItem implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_$_REF = "$ref";
    private String $ref;

    public UserSchemaPropertiesProfileItem() {
    }

    public UserSchemaPropertiesProfileItem $ref(String $ref) {

        this.$ref = $ref;
        return this;
    }

    /**
     * Get $ref
     *
     * @return $ref
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_$_REF)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public String get$Ref() {
        return $ref;
    }

    @JsonProperty(JSON_PROPERTY_$_REF)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void set$Ref(String $ref) {
        this.$ref = $ref;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        UserSchemaPropertiesProfileItem userSchemaPropertiesProfileItem = (UserSchemaPropertiesProfileItem) o;
        return Objects.equals(this.$ref, userSchemaPropertiesProfileItem.$ref);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash($ref);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class UserSchemaPropertiesProfileItem {\n");
        sb.append("    $ref: ").append(toIndentedString($ref)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}

==> okta-sdk-api-21.0.0-sources.jar: com/okta/sdk/resource/model/UserSchemaPropertiesProfileItem.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * UserSchemaPropertiesProfileItem
 */
@JsonPropertyOrder({ UserSchemaPropertiesProfileItem.JSON_PROPERTY_$_REF })
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-02-24T22:29:38.763116-06:00[America/Chicago]", comments = "Generator version: 7.11.0")
public class UserSchemaPropertiesProfileItem implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_$_REF = "$ref";
    private String $ref;

    public UserSchemaPropertiesProfileItem() {
    }

    public UserSchemaPropertiesProfileItem $ref(String $ref) {

        this.$ref = $ref;
        return this;
    }

    /**
     * Get $ref
     *
     * @return $ref
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_$_REF)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public String get$Ref() {
        return $ref;
    }

    @JsonProperty(JSON_PROPERTY_$_REF)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void set$Ref(String $ref) {
        this.$ref = $ref;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        UserSchemaPropertiesProfileItem userSchemaPropertiesProfileItem = (UserSchemaPropertiesProfileItem) o;
        return Objects.equals(this.$ref, userSchemaPropertiesProfileItem.$ref);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash($ref);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class UserSchemaPropertiesProfileItem {\n");
        sb.append("    $ref: ").append(toIndentedString($ref)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}
